@@ -186,6 +186,7 @@ bool MainContext::openUrl(const QUrl &u)
         const bool success = start(uri);
         if (success) {
             setUrl(uri);
+            setUpEnabled(url() != KIO::upUrl(url()));
         }
         return success;
     }
@@ -230,8 +231,18 @@ QUrl MainContext::url() const
 
 void MainContext::setUrl(const QUrl &url)
 {
-    m_url = url;
-    Q_EMIT urlChanged();
+    if (m_url != url) {
+        m_url = url;
+        Q_EMIT urlChanged();
+    }
+}
+
+void MainContext::setUpEnabled(const bool enabled)
+{
+    if (m_upEnabled != enabled) {
+        m_upEnabled = enabled;
+        Q_EMIT upEnabledChanged();
+    }
 }
 
 bool MainContext::start(const QUrl &url) const
